@@ -3,7 +3,7 @@ package Hash::FieldHash;
 use 5.008_001;
 use strict;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Exporter qw(import);
 our @EXPORT_OK = qw(fieldhash fieldhashes);
@@ -30,7 +30,7 @@ Hash::FieldHash - A lightweight field hash implementation
 
 =head1 VERSION
 
-This document describes Hash::FieldHash version 0.04.
+This document describes Hash::FieldHash version 0.05.
 
 =head1 SYNOPSIS
 
@@ -57,26 +57,27 @@ the inside-out technique.
 
 You may know C<Hash::Util::FieldHash>. It's a very useful module,
 but too complex to understand all the functions and only available in 5.10.
-For pre-5.10, C<H::U::FieldHash::Compat> is in CPAN, but
-it's too slow to use.
+C<H::U::F::Compat> is available for pre-5.10, but it seems too slow to use.
 
-This is an alternative to C<H::U::F> with new features:
+This is an alternative to C<H::U::F> with following features:
 
 =over 4
 
-=item Simple interface
+=item Simpler interface
 
 C<Hash::FieldHash> provides a few functions:  C<fieldhash()> and C<fieldhashes()>.
+That's enough.
 
-=item Availability in pre-5.10
+=item Higher performance
+
+C<Hash::FieldHash> is faster than C<Hash::Util::FieldHash>, because
+its internals use simpler structures.
+
+=item Relic support
 
 Although C<Hash::FieldHash> uses a new feature introduced in Perl 5.10,
 I<the uvar magic for hashes> described in L<Hash::Util::Fieldhash/"GUTS">,
-it also supports Perl 5.8 using the traditional tie-hash layer.
-
-=item High performance
-
-C<Hash::FieldHash> is faster than C<Hash::Util::FieldHash>.
+it supports Perl 5.8 using the traditional tie-hash layer.
 
 =back
 
@@ -100,36 +101,38 @@ Returns nothing.
 
 =back
 
-=head1 FEATURES
+=head1 ROBUSTNESS
 
 =head2 Thread support
 
 As C<Hash::Util::FieldHash> does, C<Hash::FieldHash> fully supports threading
 using the C<CLONE> method.
 
-=head2 Relic support
+=head2 Memory leaks
 
-Available in pre-5.10.
+C<Hash::FieldHash> itself does not leak memory, but it may leak memory when
+you uses hash references as field hash keys because of an issue of perl 5.10.0.
 
 =head1 NOTES
 
 =head2 The type of field hash keys
 
 C<Hash::FieldHash> accepts only references and registered addresses as its
-keys, whereas C<Hash::Util::FieldHash> accepts any scalars.
+keys, whereas C<Hash::Util::FieldHash> accepts any type of scalars.
 
 According to L<Hash::Util::FieldHash/"The Generic Object">,
 Non-reference keys in C<H::U::F> are used for class fields. That is,
 all the fields defined by C<H::U::F> act as both object fields and class fields
-by default. If you do not want them to be class fields, you must check the type
-of I<$self> explicitly. In addition, these class fields are never inherited.
-This function of C<H::U::F> seems erroneous, so C<Hash::FieldHash>
+by default. It seems confusing; if you do not want them to be class fields,
+you must check the type of I<$self> explicitly. In addition,
+these class fields are never inherited.
+This behavior seems problematic, so C<Hash::FieldHash>
 restricts the type of keys.
 
 =head2 The ID of field hash keys
 
 While C<Hash::Util::FieldHash> uses C<refaddr> as the IDs of field
-hash keys, C<Hash::FieldHash> allocates arbitrary natural numbers as the
+hash keys, C<Hash::FieldHash> allocates arbitrary integers as the
 IDs.
 
 =head1 DEPENDENCIES
@@ -150,6 +153,8 @@ L<Hash::Util::FieldHash::Compat>.
 
 L<perlguts/"Magic Virtual Tables">.
 
+L<Class::Std> describes the inside-out technique.
+
 =head1 AUTHOR
 
 Goro Fuji E<lt>gfuji(at)cpan.orgE<gt>.
